equal property
Whether to generate a ==/hashcode or not
If null, picks up the default values from the project's build.yaml.
If that value is null too, generates a ==/hashcode only if the class
does not have a custom ==
Implementation
final bool? equal;