imports_bindings
library
Classes
Assert
A decorator that allows adding assert(...) on the generated classes.
DeepCollectionEquality
Deep equality on collections.
Default
Allows passing default values to a constructor:
EqualUnmodifiableListView <T >
An UnmodifiableListView which overrides ==
EqualUnmodifiableMapView <Key , Value >
An UnmodifiableMapView which overrides ==
EqualUnmodifiableSetView <T >
An UnmodifiableSetView which overrides ==
Freezed
Flags a class as needing to be processed by Freezed and allows passing options.
FreezedMapOptions
Options for enabling/disabling specific Union.map features;
FreezedUnionValue
An annotation used to specify how a union type will be serialized.
FreezedWhenOptions
Options for enabling/disabling specific Union.when features;
Immutable
Annotation on an immutable class.
Implements <T extends Object ? >
Marks a union type to implement the interface stringType or type T.
In the case below City will implement AdministrativeArea<House>.
JsonConverter <T , S >
Implement this class to provide custom converters for a specific Type .
JsonEnum
Allows configuration of how enum elements are treated as JSON.
JsonKey
An annotation used to specify how a field is serialized.
JsonLiteral
An annotation used to generate a private field containing the contents of a
JSON file.
JsonSerializable
An annotation used to specify a class to generate code for.
JsonValue
An annotation used to specify how a enum value is serialized.
RecordUse
Annotation on static method or class whose accesses will be recorded.
Required
Annotation on a required named parameter.
UseResult
Annotation on function or property whose value must not be ignored.
With <T extends Object ? >
Marks a union type to mixin the interface stringType or type T.
In the case below City will mixin with AdministrativeArea<House>.
Constants
alwaysThrows
→ const Object
Annotation marking a function as always throwing.
awaitNotRequired
→ const Object
Annotation on asynchronous function whose Future can be ignored.
checked
→ const Object
Annotation that no longer has any effect.
doNotStore
→ const Object
Annotation on function or property whose value must not be stored.
doNotSubmit
→ const Object
Annotation marking declaration that should be removed before publishing.
experimental
→ const Object
Annotation marking declaration as experimental and subject to change.
factory
→ const Object
Annotation on a function that creates new objects.
freezed
→ const Freezed
Defines an immutable data-class.
immutable
→ const Immutable
Annotation on an immutable class.
internal
→ const Object
Annotation on declaration that should not be used outside of its package.
isTest
→ const Object
Annotation on a test framework function that introduces a single test.
isTestGroup
→ const Object
Annotation on a test framework function that introduces a group of tests.
literal
→ const Object
Annotation on constructor that must be invoked with const if possible.
mustBeConst
→ const Object
Annotation on a parameter whose arguments must be constants.
mustBeOverridden
→ const Object
Annotation on instance members that must be overridden by subclasses.
mustCallSuper
→ const Object
Annotation on instance member that overriding members must call.
nonVirtual
→ const Object
Annotation on instance member that must not be overridden.
optionalTypeArgs
→ const Object
Annotation on type arguments that can safely be omitted.
protected
→ const Object
Annotation on instance member that should only be used by subclasses.
redeclare
→ const Object
Annotation on extension type members which redeclare superinterface members.
reopen
→ const Object
Annotation on declaration with less access restrictions than superinterface.
required
→ const Required
Annotation on named parameter that should always have an argument supplied.
sealed
→ const Object
Annotation on class that must not be subclassed outside of its package.
unfreezed
→ const Freezed
Defines a potentially mutable data-class.
useResult
→ const UseResult
Annotation on function or property whose value must not be ignored.
virtual
→ const Object
Annotation which no longer has any effect.
visibleForOverriding
→ const Object
Annotation on declaration that should not be used outside of its package.
visibleForTesting
→ const Object
Annotation on a public declaration that should only be used in tests.
Functions
$checkedConvert <T > (Map map , String key , T castFunc (dynamic ), {Object ? readValue (Map , String )? })
→ T
Helper function used in generated code when
JsonSerializableGenerator.checked is true.
$checkedCreate <T > (String className , Map map , T constructor (S <S >(String , S (Object ? ), {Object ? readValue (Map , String )? }) ), {Map <String , String > fieldKeyMap = const {} })
→ T
Helper function used in generated code when
JsonSerializableGenerator.checked is true.
$checkedNew <T > (String className , Map map , T constructor (), {Map <String , String > ? fieldKeyMap })
→ T
Helper function used in generated code when
JsonSerializableGenerator.checked is true.
$checkKeys (Map map , {List <String > ? allowedKeys , List <String > ? requiredKeys , List <String > ? disallowNullValues })
→ void
Helper function used in generated fromJson code when
JsonSerializable.disallowUnrecognizedKeys is true for an annotated type or
JsonKey.required is true for any annotated fields.
$enumDecode <K extends Enum , V > (Map <K , V > enumValues , Object ? source , {K? unknownValue })
→ K
Returns the key associated with value source from enumValues, if one
exists.
$enumDecodeNullable <K extends Enum , V > (Map <K , V > enumValues , Object ? source , {Enum ? unknownValue })
→ K?
Returns the key associated with value source from enumValues, if one
exists.
Exceptions / Errors
ApiException
Custom exception class for handling API-related errors.
BadKeyException
A base class for exceptions thrown when decoding JSON.
CheckedFromJsonException
Exception thrown if there is a runtime exception in fromJson
code generated when JsonSerializableGenerator.checked is true
DisallowedNullValueException
Exception thrown if there are keys with disallowed null values in a JSON
map that was provided during deserialization.
MissingRequiredKeysException
Exception thrown if there are missing required keys in a JSON map that was
provided during deserialization.
UnrecognizedKeysException
Exception thrown if there are unrecognized keys in a JSON map that was
provided during deserialization.